@@ -22,7 +22,7 @@
 #'    message('Please choose the epitweetr data directory')
 #'    setup_config(file.choose())
 #'
-#'    # calculating alerts for last day tweets and sending emails to subscriptors
+#'    # calculating alerts for last day tweets and sending emails to subscribers
 #'    generate_alerts()
 #' }
 #' @seealso 
@@ -37,9 +37,11 @@
 generate_alerts <- function(tasks = get_tasks()) {
   tasks <- tryCatch({
     tasks <- update_alerts_task(tasks, "running", "processing", start = TRUE)
+    # detecting alerts for the last aggregated date
     tasks <- do_next_alerts(tasks)
 
     tasks <- update_alerts_task(tasks, "running", "sending emails")
+    # Sending email alerts 
     tasks <- send_alert_emails(tasks)
     # Setting status to succes
     tasks <- update_alerts_task(tasks, "success", "", end = TRUE)
@@ -145,7 +147,7 @@ ears_t_reweighted <- function(ts, alpha = 0.025, alpha_outlier=0.05, k_decay = 4
       e <- (y_historic - y0bar)
       #Diagonal of hat matrix - analytic
       pii <- rep(1/no_historic, no_historic)
-      # Hat matrix from regression with i'th observation removed is always they same for intercept only model
+      # Hat matrix from regression with i'th observation removed is always the same for intercept only model
       Xi <- matrix(rep(1, n-1))
       #P_noi <- Xi %*% solve( t(Xi) %*% Xi) %*% t(Xi)
       #same for the intercept only model, but probably faster: 
@@ -179,30 +181,32 @@ ears_t_reweighted <- function(ts, alpha = 0.025, alpha_outlier=0.05, k_decay = 4
 }
 
 
-# Getting alert daily counts taking in consideration a 24 hour sliding window since last full hour
+# Getting alert daily counts taking in consideration a 24-hour sliding window since last full hour
+# the provided dataset is expected to be an hourly counts by date with the following columns: tweets, known_users, created_date, created_hour
+# a new column reporting date will be added
 get_reporting_date_counts <- function(
     df = get_aggregates("country_counts")
     , topic
     , start = NA
     , end = NA
+    , last_day = get_aggregated_period("country_counts")$last
   ) {
   `%>%` <- magrittr::`%>%`
   if(nrow(df)>0) {
-    last_day <- max(as.Date(df$created_date))
     # Calculating end day hour which is going to be the last fully collected hour when 
-    # requesting the last colleted dates or 23h if it is a fully collected day 
+    # requesting the last collected dates or 23 hours if it is a fully collected day 
     last_full_hour <- (
       if(!is.na(end) && end < last_day) 
         23
       else
         as.integer(strftime(max(as.POSIXlt(df$created_date) + (as.integer(df$created_hour) - 1) * 3600), "%H"))
     )
-    #Handling going to previous day if lastèfull hour is negative
+    #Handling going to previous day if last full hour is negative
     if(last_full_hour < 0) {
       last_full_hour = 23
       last_day <- last_day - 1  
     }
-    # Setting the reporting date based on the cutoff hour
+    # Setting the reporting date based on the cut-off hour
     df$reporting_date <- ifelse(df$created_hour <= last_full_hour, df$created_date, df$created_date + 1)
 
     # filtering by start date
@@ -380,7 +384,7 @@ calculate_regions_alerts <- function(
 }
 
 
-# get alert count start depending on the baseline type: any day ort same weekday
+# get alert count start depending on the baseline type: any day or same weekday
 get_alert_count_from <- function(date, baseline_size, same_weekday_baseline) {
   if(!same_weekday_baseline)
     date - (baseline_size + 2)
@@ -388,7 +392,7 @@ get_alert_count_from <- function(date, baseline_size, same_weekday_baseline) {
     date - (7 * baseline_size + 2)
 }
 
-# getting paramerters for current alert generation
+# getting parameters for current alert generation
 # This will be based on last successfully aggregated date and it will only be generated if once each scheduling span
 do_next_alerts <- function(tasks = get_tasks()) {
   `%>%` <- magrittr::`%>%`
@@ -431,7 +435,7 @@ do_next_alerts <- function(tasks = get_tasks()) {
     #  parallel::clusterExport(cl, list("conf", "topics", "regions", "alert_to", "calculate_regions_alerts", "get_country_items", "get_country_items", "calculate_alerts"), envir=environment())
     #  alerts <- parallel::parLapply(cl, topics, function(topic) {
     
-    # calculating aletrts per topic
+    # calculating alerts per topic
     alerts <- lapply(topics, function(topic) {
       m <- paste("Getting alerts for",topic, alert_to) 
       message(m)  
@@ -559,7 +563,7 @@ do_next_alerts <- function(tasks = get_tasks()) {
 #' @importFrom utils head
 get_alerts <- function(topic=character(), countries=numeric(), from="1900-01-01", until="2100-01-01") {
   `%>%` <- magrittr::`%>%`
-  # preparing filers dealing with possible names collitions with dataframe
+  # preparing filers and renaming variables with names as column on dataframe to avoid conflicts
   regions <- get_country_items()
   t <- topic
   cnames <- ( 
@@ -579,13 +583,13 @@ get_alerts <- function(topic=character(), countries=numeric(), from="1900-01-01"
       f <- file(alert_file, "rb")
       df <- jsonlite::stream_in(f, verbose = FALSE)
       close(f)
-      # Adding default valur for same_weekday_baseline if does not exists
+      # Adding default value for same_weekday_baseline if does not exists
       if(!("same_weekday_baseline" %in% colnames(df)))
         df$same_weekday_baseline <- sapply(df$topic, function(t) FALSE)
-      # Adding default valur for alpha_outlier if does not exists
+      # Adding default value for alpha_outlier if does not exists
       if(!("alpha_outlier" %in% colnames(df)))
         df$alpha_outlier <- as.numeric(sapply(df$topic, function(t) NA))
-      # Adding default valur for k_decay if does not exists
+      # Adding default value for k_decay if does not exists
       if(!("k_decay" %in% colnames(df)))
         df$k_decay <- as.numeric(sapply(df$topic, function(t) NA))
 
@@ -617,7 +621,7 @@ get_subscribers <-function() {
   df
 }
 
-# Send email alerts to subscribers based on newly geberated alerts and subscribers configuration
+# Send email alerts to subscribers based on newly generated alerts and subscribers' configuration
 send_alert_emails <- function(tasks = get_tasks()) {
   `%>%` <- magrittr::`%>%`
   task <- tasks$alerts 
@@ -625,8 +629,10 @@ send_alert_emails <- function(tasks = get_tasks()) {
   if(!exists("sent", tasks$alerts)) tasks$alerts$sent <- list()
   # Getting subscriber users
   subscribers <- get_subscribers()
+  # iterating for each subscriber
   if(nrow(subscribers)>0) {
     for(i in 1:nrow(subscribers)) {
+      # getting values subsriber settings 
       user <- subscribers$User[[i]]
       topics <- if(is.na(subscribers$Topics[[i]])) NA else strsplit(subscribers$Topics[[i]],";")[[1]]
       dest <- if(is.na(subscribers$Email[[i]])) NA else strsplit(subscribers$Email[[i]],";")[[1]]
@@ -651,7 +657,7 @@ send_alert_emails <- function(tasks = get_tasks()) {
           )
         }
       )
-      # Adding users statistics if does not existd already
+      # Adding users' statistics if these do not exist already
       if(!exists(user, where=tasks$alerts$sent)) 
         tasks$alerts$sent[[user]] <- list()
       # Getting last day alerts date period
@@ -683,6 +689,7 @@ send_alert_emails <- function(tasks = get_tasks()) {
         current_minutes <- as.numeric(strftime(Sys.time(), format="%M"))
         current_hour <- as.numeric(strftime(Sys.time(), format="%H")) + current_minutes / 60
         
+        # Getting the current slot
         current_slot <- (
           if(all(is.na(slots))) 
             as.integer(current_hour)
@@ -692,6 +699,7 @@ send_alert_emails <- function(tasks = get_tasks()) {
             max(slots[slots <= current_hour])
         )
         
+        # Evaluating if slot alerts should be sent
         send_slot_alerts <- (
           all(is.na(slots)) ||  
           (length(slots[slots <= current_hour])>0 && # After first slot in day AND
@@ -702,7 +710,7 @@ send_alert_emails <- function(tasks = get_tasks()) {
           )
         ) 
             
-        # Filtering out alerts that are not instant if  not respect the defined slots
+        # Filtering out alerts that are not instant if these do not respect the defined slots
         instant_alerts <- user_alerts %>% dplyr::filter(
           (!all(is.na(realtime_topics)) | !all(is.na(realtime_regions))) & 
           (
@@ -722,6 +730,7 @@ send_alert_emails <- function(tasks = get_tasks()) {
             instant_alerts
         )
         
+        # getting slot alerts
         slot_alerts <- user_alerts %>% dplyr::filter(
          ( (all(is.na(realtime_topics)) & all(is.na(realtime_regions))) |
           (
@@ -732,7 +741,7 @@ send_alert_emails <- function(tasks = get_tasks()) {
           & send_slot_alerts 
         )
         
-        # Excluding instant alerts produced before the last alert sent to user
+        # Excluding slot alerts produced before the last alert sent to user
         slot_alerts <- (
           if(exists("date", where = tasks$alerts$sent[[user]]) && 
             exists("hour_slot", where = tasks$alerts$sent[[user]]) &&
@@ -777,7 +786,7 @@ send_alert_emails <- function(tasks = get_tasks()) {
             )
           )
           # Creating email body
-          # Getting an array of countries with alerts sorted on descending ordrt by the total number of tweets
+          # Getting an array of countries with alerts sorted on descending order by the total number of tweets
           topics_with_alerts <- (
             user_alerts %>% 
             dplyr::group_by(.data$topic) %>% 
@@ -832,6 +841,7 @@ send_alert_emails <- function(tasks = get_tasks()) {
           html <- gsub("@alerts", paste(alert_tables, collapse="\n"), html)
           close(t_con)
 
+          # creating the message to send
           msg <- ( 
             emayili::envelope() %>% 
             emayili::from(conf$smtp_from) %>% 
